function map_christoffel,projection,lat,lon,metric=g

rad=57.2957

phi=lat/rad
del=1e-4
dlat=double([[-del,0,del],[-del,0,del],[-del,0,del]])
dlon=double([[-del,-del,-del],[0,0,0],[del,del,del]])

;; The background metric
gbar_inv=[[1,0],[0,1/cos(phi)^2]]
gbar=[[1,0],[0,cos(phi)^2]]

deproject,x1,y1,lat+dlat,lon+dlon,projection=projection,forward=1

lam=dblarr(2,2)*0

lam[0,0]=(x1[2,1]-x1[0,1])/(2.*del)
lam[0,1]=(x1[1,2]-x1[1,0])/(2.*del)
lam[1,0]=(y1[2,1]-y1[0,1])/(2.*del)
lam[1,1]=(y1[1,2]-y1[1,0])/(2.*del)
lam_inv=invert(lam)

g=dblarr(2,2)*0
for a=0,1 do begin
    for b=0,1 do begin
        g[a,b]=0
        for c=0,1 do begin
            for d=0,1 do begin
                g[a,b]=g[a,b]+gbar[c,d]*lam_inv[c,a]*lam_inv[d,b]
            endfor
        endfor
    endfor
endfor
g_inv=invert(g)

dlam=dblarr(2,2,2)
dlam[0,0,0]=(x1[2,1]+x1[0,1]-2*x1[1,1])/del^2
dlam[1,0,0]=(y1[2,1]+y1[0,1]-2*y1[1,1])/del^2
dlam[0,1,1]=(x1[1,2]+x1[1,0]-2*x1[1,1])/del^2
dlam[1,1,1]=(y1[1,2]+y1[1,0]-2*y1[1,1])/del^2
dlam[0,0,1]=(x1[2,2]+x1[0,0]-x1[2,0]-x1[0,2])/(4*del^2)
dlam[1,0,1]=(y1[2,2]+y1[0,0]-y1[2,0]-y1[0,2])/(4*del^2)
dlam[0,1,0]=dlam[0,0,1]
dlam[1,1,0]=dlam[1,0,1]

dg_inv=dblarr(2,2,2)*0


;; We also need to compute the derivatives of the
;; metric...
for a=0,1 do begin
    for b=0,1 do begin
        for c=0,1 do begin
            dg_inv[a,b,c]=lam[a,1]*lam[b,1]*lam_inv[0,c]*2*(tan(phi)/cos(phi)^2)/rad
            for abar=0,1 do begin
                for bbar=0,1 do begin
                    for cbar=0,1 do begin
                        dg_inv[a,b,c]=dg_inv[a,b,c]+$
                          dlam[a,abar,cbar]*lam[b,bbar]*lam_inv[cbar,c]*gbar_inv[abar,bbar]+$
                          dlam[b,bbar,cbar]*lam[a,abar]*lam_inv[cbar,c]*gbar_inv[abar,bbar]
                    endfor
                endfor
            endfor
        endfor
    endfor
endfor

dg=dblarr(2,2,2)*0
for a=0,1 do begin
    for b=0,1 do begin
        for c=0,1 do begin
            dg[a,b,c]=0
            for d=0,1 do begin
                for e=0,1 do begin
                    dg[a,b,c]=dg[a,b,c]+g[a,d]*g[b,e]*dg_inv[d,e,c]
                endfor
            endfor
        endfor
    endfor
endfor

Gam=dblarr(2,2,2)

for a=0,1 do begin
    for b=0,1 do begin
        for c=0,1 do begin
            Gam[a,b,c]=0
            for d=0,1 do begin
                Gam[a,b,c]=Gam[a,b,c]+0.5*g_inv[a,d]*(dg[b,d,c]+dg[c,d,b]-dg[b,c,d])
            endfor
        endfor
    endfor
endfor

return,Gam

end
