pro map_flexion,projection,r0=r0,latmax=latmax,latmin=latmin,latcurve=latcurve,loncurve=loncurve,strict=strict,outfile=outfile
 
if keyword_set(outfile) then begin
    set_plot,'ps'
    device,file=outfile,/color,bits=8
endif else begin
    window,0,xsize=1000,ysize=1000
endelse

lonmin=-180
lonmax=180

if not keyword_set(latmax) then latmax=90.
if not keyword_set(latmin) then latmin=-90.

if not keyword_set(latcurve) then latcurve=0

if not keyword_set(loncurve) then loncurve=0

if not keyword_set(strict) then strict=0

;print,latcurve


; Set some parameters
rad=57.2957
npts=200
dlon0=fltarr(npts)
dlat0=fltarr(npts)
ux_arr=fltarr(npts)
uy_arr=fltarr(npts)
if not keyword_set (r0) then begin
    r0=12
endif

; first create an outline...
noutline=400
n4=noutline/4
lat_outline=dblarr(noutline)
lon_outline=dblarr(noutline)

if (projection ne "gnomonic_cube") then begin
    for i=0,n4-1 do begin
        lat_outline[i]=latmin
        lon_outline[i]=lonmin+i/(n4-1.)*float(lonmax-lonmin)
        
        lat_outline[i+n4]=latmin+i/(n4-1.)*(latmax-latmin)
        lon_outline[i+n4]=lonmax
        
        lat_outline[i+2*n4]=latmax
        lon_outline[i+2*n4]=lonmax-i/(n4-1.)*float(lonmax-lonmin)
        
        lat_outline[i+3*n4]=latmax-i/(n4-1.)*(latmax-latmin)
        lon_outline[i+3*n4]=lonmin
    endfor
    deproject,x_outline,y_outline,lat_outline,lon_outline,projection=projection,forward=1
endif else begin
    x_outline=[-3,-1,-1,1,1,5,5,1,1,-1,-1,-3,-3]
    y_outline=[-1,-1,-3,-3,-1,-1,1,1,3,3,1,1,-1]
endelse

plot,x_outline,y_outline,/isotropic,xstyle=4,ystyle=4,COLOR=0,BACKGROUND=-1

;read in the continents
close,1
openr,1,'supmap.dat',/xdr,/stream
npts1=0L
nsegs=283
for i=1,nsegs do begin
    readu,1,npts1,maxlat,minlat,maxlon,minlon
    npts1=npts1/2
    latlon=fltarr(2,npts1)
    readu,1,latlon
    idx=where(latlon[0,*] gt latmin and latlon[0,*] lt latmax,nin)
    if (nin gt 0) then begin
        deproject,x,y,latlon[0,idx],latlon[1,idx],projection=projection,forward=1
        if strict eq 0 then begin
            oplot,x,y,color=0
        endif else plot_strict,x,y,projection
    endif
endfor
close,1
;read,idum

;; Set some arrays for curvature measurements.
;del=1e-4
;dlat=double([[-del,0,del],[-del,0,del],[-del,0,del]])
;dlon=double([[-del,-del,-del],[0,0,0],[del,del,del]])
;lam=dblarr(2,2)
;dlam=dblarr(2,2,2)
;lam_inv=dblarr(2,2)
;dg_inv=dblarr(2,2,2)
;dg=dblarr(2,2,2)
ntheta=400
theta=indgen(ntheta)*2*3.14159/float(ntheta)
u1=dblarr(2,ntheta)
u1[0,*]=cos(theta)
u1[1,*]=sin(theta)
rinv=dblarr(ntheta)
Gam=dblarr(2,2,2)
;g=dblarr(2,2)



for lat=-60,60,30 do begin
    if lat ge latmin and lat le latmax then begin
        for lon=lonmin,lonmax,60 do begin
            ;print,lat,lon


            ux=1./cos(lat/rad)
            uy=0
            dlon0[0]=0
            dlat0[0]=0
            dtau=4.*r0/float(npts)
            for i=1,npts/4-1 do begin
                dlon0[i]=dlon0[i-1]+ux*dtau
                dlat0[i]=dlat0[i-1]+uy*dtau
                ux=ux+2*tan((lat+dlat0[i])/rad)/rad*ux*uy*dtau
                uy=uy-0.5*sin(2*(lat+dlat0[i])/rad)/rad*ux*ux*dtau
            endfor
            ux=-1./cos(lat/rad)
            uy=0
            dlon0[npts/4]=0
            dlat0[npts/4]=0
            for i=npts/4+1,npts/2-1 do begin
                dlon0[i]=dlon0[i-1]+ux*dtau
                dlat0[i]=dlat0[i-1]+uy*dtau
                ux=ux+2*tan((lat+dlat0[i])/rad)/rad*ux*uy*dtau
                uy=uy-0.5*sin(2*(lat+dlat0[i])/rad)/rad*ux*ux*dtau
            endfor
            for i=0,npts/2-1 do begin
                dlon0[i+npts/2]=0
                dlat0[i+npts/2]=-r0+2.*r0*(i+0.5)/(npts/2)
            endfor
            deproject,x,y,lat+dlat0,lon+dlon0,projection=projection,forward=1
            
            idx=where((lon+dlon0)[0:npts/4-1] ge lonmin and (lon+dlon0)[0:npts/4-1] le lonmax)
            if strict eq 0 then begin
                oplot,x[idx],y[idx] ,color=0
            endif else plot_strict,x[idx],y[idx],projection
            idx=where((lon+dlon0)[npts/4:npts/2-1] ge lonmin and (lon+dlon0)[npts/4:npts/2-1] le lonmax)+npts/4
            if strict eq 0 then begin
                oplot,x[idx],y[idx] ,color=0
            endif else plot_strict,x[idx],y[idx],projection
            idx=where((lon+dlon0)[npts/2:*] ge lonmin and (lon+dlon0)[npts/2-1:*] le lonmax)+npts/2
            if strict eq 0 then begin
                oplot,x[idx],y[idx] ,color=0
            endif else plot_strict,x[idx],y[idx],projection
            
            
                                ; Also for ellipse plotting...
            for i=0,npts-1 do begin
                ux_arr[i]=1./cos(lat/rad)*cos(2.*3.14159*i/float(npts))
                uy_arr[i]=1.*sin(2*3.14159*i/float(npts))
            endfor
            dtau=r0/float(npts)
            dlat0=dlat0*0
            dlon0=dlon0*0
            for i=0,npts-1 do begin
                dlon0=dlon0+ux_arr*dtau
                dlat0=dlat0+uy_arr*dtau
                ux_arr=ux_arr+2*tan((lat+dlat0)/rad)/rad*ux_arr*uy_arr*dtau
                uy_arr=uy_arr-0.5*sin(2*(lat+dlat0)/rad)/rad*ux_arr*ux_arr*dtau
            endfor
            ; Make this the tissot
            ;deproject,x,y,lat+0.01*dlat0,lon+0.01*dlon0,projection=projection,forward=1
            
            deproject,x,y,lat+dlat0,lon+dlon0,projection=projection,forward=1
            
            ; Make this the tissot
            ;x0=mean(x)
            ;y0=mean(y)
            ;x=x0+100*(x-x0)
            ;y=y0+100*(y-y0)


            idx=where((lon+dlon0)ge lonmin and (lon+dlon0)le lonmax)

            tmp=idx-shift(idx,1)
            idx2=where(tmp ne 1 and tmp ge 0,nbreak)
            if nbreak eq 0 then begin
                if strict eq 0 then begin
                    oplot,x[idx],y[idx],color=0
                endif else plot_strict,x[idx],y[idx],projection
            endif else begin
                if strict eq 0 then begin
                    oplot,x[idx[0:idx2[0]-1]],y[idx[0:idx2[0]-1]],color=0
                    oplot,x[idx[idx2[nbreak-1]:*]],y[idx[idx2[nbreak-1]:*]],color=0
                endif else begin 
                    plot_strict,x[idx[0:idx2[0]-1]],y[idx[0:idx2[0]-1]],projection
                    plot_strict,x[idx[idx2[nbreak-1]:*]],y[idx[idx2[nbreak-1]:*]],projection
                endelse
            endelse

            ;if lat eq latcurve and lon eq loncurve then begin
            ;    Gam=map_christoffel(projection,lat,lon,metric=g)
            ;    get_f_s,f,s,u1,Gam,g
            ;endif
        endfor
    endif
endfor

if keyword_set(outfile) then begin
    device,/close
    set_plot,'x'
endif


end
