FUNCTION map_getindex,indx, error
;
; Used to read in the index file for
; each map data file.  On successful completion, error is set to 0.
;
COMPILE_OPT hidden

openr, lun, indx, /xdr, /get_lun, error = error
if error ne 0 then return, 0            ;File not there or unreadable
segments=0L & readu, lun, segments
dx_map=replicate({ fptr:0L, npts:0L,latmax:0.,latmin:0.,$
                   lonmax:0.,lonmin:0. }, segments )
readu, lun, dx_map & free_lun, lun
free_lun,lun
return, dx_map
END

;;

pro rotate_positions,lat_out,lon_out,lat_in,lon_in,dlat,dlon
; Rotate longitude first
rad=57.2957

lambda=(lon_in+dlon)/rad
phi=(lat_in)/rad
theta=dlat/rad

x=cos(theta)*cos(phi)*cos(lambda)-sin(theta)*sin(phi)
y=cos(phi)*sin(lambda)
z=sin(theta)*cos(phi)*cos(lambda)+cos(theta)*sin(phi)

lat_out=rad*(asin(z))
lon_out=rad*atan(y/x)
idx1=where (x lt 0 and y gt 0,n1)
if (n1 gt 0) then begin
    lon_out[idx1]=lon_out[idx1]+180
endif
idx2=where(x lt 0 and y lt 0,n2)
if (n2 gt 0) then begin
    lon_out[idx2]=lon_out[idx2]-180
endif



END

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

pro map_us,projection,latcenter=latcenter,loncenter=loncenter,outfile=outfile
; Plot a map of the continental united states, and draw an indicatrix
; at the geographic center.


rad=57.2957
npts=200
r0=12.
dtau=4.*r0/float(npts)
; The geographic center of the contintal us is lat=39.86, lon=-98.6

lat0_boundaries=[39.86,39.86,39.86,55,25]
lon0_boundaries=[-98.6,-133.6,-63.6,-98.6,-98.6]

if not keyword_set(latcenter) then begin
    dlat=0
endif else begin
    dlat=latcenter-lat0_boundaries[0]
endelse

if not keyword_set(loncenter) then begin
    dlon=0
endif else begin
    dlon=loncenter-lon0_boundaries[0]
endelse

if not keyword_set(outfile) then begin
    window,0,xsize=1000,ysize=1000
endif else begin
    set_plot,'ps'
    device,file=outfile,/color,bits=8
endelse

latmin=min(lat0_boundaries)
latmax=max(lat0_boundaries)
lonmin=min(lon0_boundaries)
lonmax=max(lon0_boundaries)

;; First, if necessary, rotate the geographic center appropriately...
rotate_positions,lat_boundaries,lon_boundaries,lat0_boundaries,lon0_boundaries,dlat,dlon
deproject,x_boundaries,y_boundaries,lat_boundaries,lon_boundaries,projection=projection,forward=1
plot,x_boundaries,y_boundaries,/isotropic,BACKGROUND=-1,COLOR=-1,psym=4

;; Read in the country borders...
;; the first 283 lines are continents, the next 325-283=42 are country
;; borders.
fndx='bhigh.ndx'
dat='bhigh.dat'
ndx=map_getindex(fndx,error)
close,1
if error eq 0 then openr, 1, dat,/xdr,/stream
count=n_elements(ndx)
for i=0,count -1 do begin
    latlon=fltarr(2,ndx[i].npts)
    readu,1,latlon
    idx=where(latlon[0,*] ge latmin and latlon[0,*] le latmax and latlon[1,*] ge lonmin and $
              latlon[1,*] le lonmax,n)
    if (n gt 0) then begin
        rotate_positions,lat,lon,latlon[0,idx],latlon[1,idx],dlat,dlon
        deproject,x,y,lat,lon,projection=projection,forward=1
        oplot,x,y,color=0
    endif
endfor
close,1
openr,1,'supmap.dat',/xdr,/stream
npts1=0L
nsegs=283
for i=1,nsegs do begin
    readu,1,npts1,maxlat,minlat,maxlon,minlon
    npts1=npts1/2
    latlon=fltarr(2,npts1)

    readu,1,latlon
    idx=where(latlon[0,*] ge latmin and latlon[0,*] le latmax and latlon[1,*] ge lonmin and $
              latlon[1,*] le lonmax,n)
    if (n gt 0) then begin
        rotate_positions,lat,lon,latlon[0,idx],latlon[1,idx],dlat,dlon
        deproject,x,y,lat,lon,projection=projection,forward=1
        oplot,x,y,color=0
    endif
endfor
close,1



;; Now plot the GG indicatrix in Kansas...

lat=39.86
lon=-98.6

ux=1./cos(lat/rad)
uy=0
dlon0=dblarr(npts)
dlat0=dblarr(npts)
ux_arr=dblarr(npts)
uy_arr=dblarr(npts)
dlon0[0]=0
dlat0[0]=0
dtau=4.*r0/float(npts)
for i=1,npts/4-1 do begin
    dlon0[i]=dlon0[i-1]+ux*dtau
    dlat0[i]=dlat0[i-1]+uy*dtau
    ux=ux+2*tan((lat+dlat0[i])/rad)/rad*ux*uy*dtau
    uy=uy-0.5*sin(2*(lat+dlat0[i])/rad)/rad*ux*ux*dtau
endfor
ux=-1./cos(lat/rad)
uy=0
dlon0[npts/4]=0
dlat0[npts/4]=0
for i=npts/4+1,npts/2-1 do begin
    dlon0[i]=dlon0[i-1]+ux*dtau
    dlat0[i]=dlat0[i-1]+uy*dtau
    ux=ux+2*tan((lat+dlat0[i])/rad)/rad*ux*uy*dtau
    uy=uy-0.5*sin(2*(lat+dlat0[i])/rad)/rad*ux*ux*dtau
endfor
for i=0,npts/2-1 do begin
    dlon0[i+npts/2]=0
    dlat0[i+npts/2]=-r0+2.*r0*(i+0.5)/(npts/2)
endfor
rotate_positions,lat1,lon1,lat+dlat0,lon+dlon0,dlat,dlon
deproject,x,y,lat1,lon1,projection=projection,forward=1

oplot,x[0:npts/4-1],y[0:npts/4-1] ,color=0
oplot,x[npts/4:npts/2-1],y[npts/4:npts/2-1] ,color=0
oplot,x[npts/2:npts-1],y[npts/2:npts-1] ,color=0

for i=0,npts-1 do begin
    ux_arr[i]=1./cos(lat/rad)*cos(2.*3.14159*i/float(npts))
    uy_arr[i]=1.*sin(2*3.14159*i/float(npts))
endfor
dtau=r0/float(npts)
dlat0=dlat0*0
dlon0=dlon0*0
for i=0,npts-1 do begin
    dlon0=dlon0+ux_arr*dtau
    dlat0=dlat0+uy_arr*dtau
    ux_arr=ux_arr+2*tan((lat+dlat0)/rad)/rad*ux_arr*uy_arr*dtau
    uy_arr=uy_arr-0.5*sin(2*(lat+dlat0)/rad)/rad*ux_arr*ux_arr*dtau
endfor

rotate_positions,lat1,lon1,lat+dlat0,lon+dlon0,dlat,dlon
deproject,x,y,lat1,lon1,projection=projection,forward=1
oplot,x,y,color=0




if keyword_set(outfile) then begin
    device,/close
    set_plot,'x'
endif


end

